@@ -5,9 +5,10 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Types::Standard qw( Bool );
+use WebService::TeamCity::Types qw( JSONBool );
 
 use Moo::Role;
 
@@ -15,14 +16,14 @@ requires 'status';
 
 has passed => (
     is      => 'ro',
-    isa     => Bool,
+    isa     => Bool | JSONBool,
     lazy    => 1,
     default => sub { $_[0]->status eq 'SUCCESS' },
 );
 
 has failed => (
     is      => 'ro',
-    isa     => Bool,
+    isa     => Bool | JSONBool,
     lazy    => 1,
     default => sub { $_[0]->status eq 'FAILURE' },
 );
@@ -35,13 +36,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::TeamCity::Entity::HasStatus - Role for any REST API object with a status
 
 =head1 VERSION
 
-version 0.03
+version 0.04
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/WebService-TeamCity/issues>.
 
 =head1 AUTHOR
 
@@ -49,7 +56,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc..
+This software is copyright (c) 2018 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
